@@ -1,9 +1,9 @@
 /***************************************************************************
-                          mediacontrolconfig.cpp  -  description
+                          mediacontrol configuration dialog
                              -------------------
     begin                : forgot :/
-    copyright            : (C) 2000-2003 by Stefan Gehn
-    email                : sgehn@gmx.net
+    copyright            : (C) 2000-2005 by Stefan Gehn
+    email                : metz {AT} gehn {DOT} net
 
     code-skeleton taken from knewsticker which is
     Copyright (c) Frerich Raabe <raabe@kde.org>
@@ -23,7 +23,6 @@
 #endif
 
 #include "mediacontrolconfig.h"
-#include "mediacontrolconfig.moc"
 #include "mediacontrolconfigwidget.h"
 
 #include <qdir.h>
@@ -59,13 +58,14 @@ MediaControlConfig::MediaControlConfig( ConfigFrontend *cfg, QWidget *parent, co
 	_child->playerListBox->insertItem("Noatun");
 	_child->playerListBox->insertItem("Amarok");
 	_child->playerListBox->insertItem("JuK");
+	_child->playerListBox->insertItem("mpd");
 	_child->playerListBox->insertItem("KsCD");
 
 	_child->themeListBox->clear();
 	// fill with available skins
 	KGlobal::dirs()->addResourceType("themes", KStandardDirs::kde_default("data") + "mediacontrol");
 	QStringList list = KGlobal::dirs()->resourceDirs("themes");
-	for (QStringList::ConstIterator it = list.begin(); it != list.end(); it++)
+	for (QStringList::ConstIterator it = list.constBegin(); it != list.constEnd(); ++it)
 		readSkinDir(*it);
 
 	connect(_child->mWheelScrollAmount, SIGNAL(valueChanged(int)), SLOT(slotConfigChanged()));
@@ -133,7 +133,7 @@ void MediaControlConfig::load()
 void MediaControlConfig::save()
 {
 //	kdDebug(90200) << "MediaControlConfig::save()" << endl;
-	for ( int it=0 ; it <= _child->playerListBox->numRows(); it++ )
+	for ( int it=0 ; it <= _child->playerListBox->numRows(); ++it )
 	{
 		if ( _child->playerListBox->isSelected(it) )
 		{
@@ -143,7 +143,7 @@ void MediaControlConfig::save()
 
 	_configFrontend->setMouseWheelSpeed ( _child->mWheelScrollAmount->value() );
 
-	for ( int it=0 ; it <= _child->themeListBox->numRows(); it++ )
+	for ( int it=0 ; it <= _child->themeListBox->numRows(); ++it )
 	{
 		if ( _child->themeListBox->isSelected(it) )
 		{
@@ -193,3 +193,5 @@ void MediaControlConfig::slotUseThemesToggled(bool on)
 	_child->themeListBox->setEnabled(on);
 	_child->previewGroupBox->setEnabled(on);
 }
+
+#include "mediacontrolconfig.moc"
