@@ -10,18 +10,32 @@
 
 #include "tree.h"
 
+class SchemaListAction;
+class TabWidget;
+
 class View : public KMainWindow
 {
 Q_OBJECT
+	Oblique *mOblique;
 	Tree *mTree;
+	QValueList<Tree*> mTrees;
+	TabWidget *mTabs;
+	KAction *mRemoveTabAction;
+	SchemaListAction *mSchemaListAction;
 
 public:
-	View(Oblique *oblique, Query *query);
+	View(Oblique *oblique);
+	~View();
 
 	Tree *tree() { return mTree; }
 
+	Oblique *oblique() { return mOblique; }
+
 public slots:
 	void addFiles();
+	void addDirectory();
+	void addTab();
+	void removeTab();
 
 signals:
 	void listHidden();
@@ -31,6 +45,9 @@ private slots:
 	void configureToolBars();
 	void newToolBarConfig();
 	void jumpTextChanged(const QString &text);
+	void use(Slice*);
+	void currentTabChanged(QWidget *);
+	void setSchema(const QString &file);
 
 protected:
 	virtual void showEvent(QShowEvent *) { emit listShown(); }
